/**
 * Dream
 * Copyright (C) 2003-2004 INRIA Rhone-Alpes
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Contact: dream@objectweb.org
 *
 * Initial developer(s): Matthieu Leclercq
 * Contributor(s): 
 */

package org.objectweb.dream.protocol;

import java.io.IOException;
import java.io.ObjectInput;
import java.io.ObjectOutput;

import org.objectweb.dream.message.AbstractChunk;
import org.objectweb.dream.util.Util;

/**
 * General purpose chunk containing an exception.
 */
public class ExceptionChunk extends AbstractChunk<ExceptionChunk>
{
  private static final long  serialVersionUID = -8777509475936033088L;

  /** default name of chunk of this type. */
  public static final String DEFAULT_NAME     = "exception-chunk";

  private Exception          exception;

  /**
   * Returns the exception.
   * 
   * @return the exception.
   */
  public Exception getException()
  {
    return exception;
  }

  /**
   * Sets the exception.
   * 
   * @param e an exception.
   */
  public void setException(Exception e)
  {
    exception = e;
  }

  // ---------------------------------------------------------------------------
  // Chunk methods
  // ---------------------------------------------------------------------------

  /**
   * @see AbstractChunk#newChunk()
   */
  public ExceptionChunk newChunk()
  {
    return new ExceptionChunk();
  }

  /**
   * @see AbstractChunk#transfertStateTo(AbstractChunk)
   */
  public void transfertStateTo(ExceptionChunk newInstance)
  {
    newInstance.exception = exception;
  }

  /**
   * @see org.objectweb.dream.pool.Recyclable#recycle()
   */
  public void recycle()
  {
    exception = null;
  }

  /**
   * @see java.io.Externalizable#writeExternal(java.io.ObjectOutput)
   */
  public void writeExternal(ObjectOutput out) throws IOException
  {
    Util.writeObject(out, exception);
  }

  /**
   * @see java.io.Externalizable#readExternal(java.io.ObjectInput)
   */
  public void readExternal(ObjectInput in) throws IOException,
      ClassNotFoundException
  {
    exception = (Exception) Util.readObject(in);
  }

}
