/**
 * Dream
 * Copyright (C) 2003-2004 INRIA Rhone-Alpes
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Contact: dream@objectweb.org
 *
 * Initial developer(s): Vivien Quema
 * Contributor(s): 
 */

package org.objectweb.dream.queue;

/**
 * Attribute controller for buffers that sort messages using an ascending
 * sequence number. It allows getting/setting the sequence number of the last
 * delivered message.
 */
public interface BufferAttributeControllerAscendingSequenceNumber
    extends
      BufferAttributeControllerSorted
{

  /**
   * Returns the sequence number of the last delivered message.
   * 
   * @return the sequence number of the last delivered message.
   * @throws InterruptedException if it is interrupted while waiting for the
   *           mutex to be acquired.
   */
  long getLastInSequence() throws InterruptedException;

  /**
   * Sets the sequence number of the last delivered message.
   * 
   * @param lastInSequence the sequence number to be set.
   * @throws InterruptedException if it is interrupted while waiting for the
   *           mutex to be acquired.
   */
  void setLastInSequence(long lastInSequence) throws InterruptedException;

}