/**
 * Dream
 * Copyright (C) 2003-2004 INRIA Rhone-Alpes
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Contact: dream@objectweb.org
 *
 * Initial developer(s): Matthieu Leclercq
 * Contributor(s): Vivien Quema
 */

package org.objectweb.dream.queue;

import org.objectweb.fractal.api.control.AttributeController;

/**
 * Attribute controller for queue implementation with a
 * {@link org.objectweb.dream.Push push} input. It defines an overflow policy
 * attribute with three default values (specific implementations can define
 * other).
 */
public interface PushQueueAttributeController extends AttributeController
{

  /**
   * An overflow policy that block incoming messages until a message is
   * delivered on the output. <br>
   * Warning when using this overflow policy a
   * {@link org.objectweb.dream.InterruptedPushException} may be thrown.
   */
  String BLOCK_OVERFLOW_POLICY                  = "block";

  /**
   * An overflow policy that drops a message message from the queue when it is
   * full.
   */
  String DROP_QUEUE_MESSAGE_OVERFLOW_POLICY     = "drop-queue-message";

  /**
   * An overflow policy that drops the first message of the queue when it is
   * full.
   */
  String DROP_FIRST_OVERFLOW_POLICY             = "drop-first";

  /**
   * An overflow policy that drops the last message of the queue when it is
   * full.
   */
  String DROP_LAST_OVERFLOW_POLICY              = "drop-last";

  /**
   * An overflow policy that drops the current message when the queue is full:
   * this means that the message will not be inserted into the queue.
   */
  String DROP_PROCESSED_MESSAGE_OVERFLOW_POLICY = "drop-processed-message";

  /**
   * An overflow policy that causes the <code>Push</code> server interface to
   * throw a {@link BufferOverflowException}
   */
  String EXCEPTION_OVERFLOW_POLICY              = "exception";

  /**
   * Returns the overflow policy.
   * 
   * @return the overflow policy.
   */
  String getOverflowPolicy();

  /**
   * Sets the overflow policy.
   * 
   * @param policy the overflow policy.
   * @throws IllegalArgumentException if the given string is not recognized as a
   *           valid policy.
   */
  void setOverflowPolicy(String policy);

}