/**
 * Dream
 * Copyright (C) 2003-2004 INRIA Rhone-Alpes
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Contact : dream@objectweb.org
 *
 * Initial developer(s): Matthieu Leclercq
 * Contributor(s): Vivien Quema, Romain Lenglet
 */

package org.objectweb.dream.queue.keyed;

import org.objectweb.dream.PushException;
import org.objectweb.dream.message.Message;

/**
 * Interface that allows pushing messages and associating keys with pushed
 * messages.
 */
public interface KeyedPush
{

  /**
   * The commonly used name to refer to this interface when it is used as an
   * output.
   */
  String OUT_KEYED_PUSH_ITF_NAME = "out-keyed-push";

  /**
   * The commonly used name to refer to this interface when it is used as an
   * input.
   */
  String IN_KEYED_PUSH_ITF_NAME  = "in-keyed-push";

  /**
   * Gives a message to a component.
   * 
   * @param key the key that is associated with the pushed message.
   * @param message the message to give to the component.
   * @throws PushException if an exception occurs.
   */
  void push(Message message, Object key) throws PushException;
}